@@ -9,33 +9,26 @@ class EntityMatchingAPI(ContextModelAPI):
     _RESOURCE_PATH = EntityMatchingModel._RESOURCE_PATH
     _MODEL_CLASS = EntityMatchingModel
 
-    def fit(self, items: List[str]) -> EntityMatchingModel:
-        """Fit entity matching model.
-
-        Args:
-            items: list of entities to create a model for.
-
-        Returns:
-            EntityMatchingModel: Resulting queued model."""
-        return super()._fit_model(items=list(items))
-
-    def fit_ml(
+    def fit(
         self,
         match_from: List[Union[Dict, CogniteResource]],
         match_to: List[Union[Dict, CogniteResource]],
         true_matches: List[Tuple[int, int]] = None,
         keys_from_to: List[Tuple[str, str]] = None,
-        model_type=None,
+        feature_type: str = None,
+        classifier: str = None,
+        complete_missing: bool = False,
     ) -> EntityMatchingModel:
         """Fit entity matching model with machine learning methods.
 
         Args:
             match_from: entities to match from, should have an 'id' field. Tolerant to passing more than is needed or used (e.g. json dump of time series list)
             match_to: entities to match to, should have an 'id' field.  Tolerant to passing more than is needed or used.
-            true_matches: Known valid matches given as a list of (id_from,id_to). If ommited, uses an unsupervised model.
+            true_matches: Known valid matches given as a list of (id_from,id_to). If omitted, uses an unsupervised model.
             keys_from_to: List of (from,to) keys to use in matching. Default in the API is [('name','name')]
-            model_type: model type that defines features and methods used, see API docs for details.
-
+            feature_type (str): feature type that defines the combination of features used, see API docs for details.
+            classifier (str): classifier used in training. Currently undocumented in API.
+            complete_missing (bool): whether missing data in keyFrom or keyTo should return error or be filled in with an empty string. Currently undocumented in API
         Returns:
             EntityMatchingModel: Resulting queued model."""
         if keys_from_to:
@@ -43,12 +36,40 @@ class EntityMatchingAPI(ContextModelAPI):
         if true_matches:
             true_matches = list(true_matches)
         return super()._fit_model(
-            model_path="/fitml",
+            model_path="/fit",
             match_from=EntityMatchingModel.dump_entities(match_from),
             match_to=EntityMatchingModel.dump_entities(match_to),
             true_matches=true_matches,
             keys_from_to=keys_from_to,
-            model_type=model_type,
+            feature_type=feature_type,
+            classifier=classifier,
+            complete_missing=complete_missing,
+        )
+
+    def fit_ml(
+        self,
+        match_from: List[Union[Dict, CogniteResource]],
+        match_to: List[Union[Dict, CogniteResource]],
+        true_matches: List[Tuple[int, int]] = None,
+        keys_from_to: List[Tuple[str, str]] = None,
+        feature_type: str = None,
+        classifier: str = None,
+        complete_missing: bool = False,
+    ) -> EntityMatchingModel:
+        """Duplicate of fit will eventually be removed"""
+        if keys_from_to:
+            keys_from_to = [{"keyFrom": f, "keyTo": t} for f, t in keys_from_to]
+        if true_matches:
+            true_matches = list(true_matches)
+        return super()._fit_model(
+            model_path="/fit",
+            match_from=EntityMatchingModel.dump_entities(match_from),
+            match_to=EntityMatchingModel.dump_entities(match_to),
+            true_matches=true_matches,
+            keys_from_to=keys_from_to,
+            feature_type=feature_type,
+            classifier=classifier,
+            complete_missing=complete_missing,
         )
 
     def create_rules(self, matches: List[Dict]) -> ContextualizationJob:
