@@ -6,13 +6,14 @@ from cognite.client._api.files import FilesAPI
 from cognite.client._api_client import APIClient
 from cognite.client._cognite_client import CogniteClient as Client
 from cognite.experimental._api.assets import ExperimentalAssetsAPI
+from cognite.experimental._api.document_parsing import DocumentParsingAPI
 from cognite.experimental._api.entity_extraction import EntityExtractionAPI
 from cognite.experimental._api.entity_matching import EntityMatchingAPI
 from cognite.experimental._api.functions import FunctionsAPI
 from cognite.experimental._api.model_hosting import ModelHostingAPI
 from cognite.experimental._api.pnid_parsing import PNIDParsingAPI
 from cognite.experimental._api.relationships import RelationshipsAPI
-from cognite.experimental._api.resource_typing import ResourceTypingAPI
+from cognite.experimental._api.schema_completion import SchemaCompletionAPI
 from cognite.experimental._api.types import TypesAPI
 from cognite.experimental._api.unstructured import GrepAPI
 
@@ -29,7 +30,9 @@ APIClient.RETRYABLE_POST_ENDPOINTS |= {
     "/files/unstructured/downloadlink/parsed",
 }
 APIClient.RETRYABLE_POST_ENDPOINTS |= {
-    f"/{api}/{endpoint}" for api in ["types", "labels", "relationships"] for endpoint in ["list", "byids", "search"]
+    f"/{api}/{endpoint}"
+    for api in ["types", "labels", "relationships", "functions"]
+    for endpoint in ["list", "byids", "search"]
 }
 
 
@@ -90,8 +93,10 @@ class CogniteClient(Client):
         self.assets_playground = ExperimentalAssetsAPI(self._config, api_version="playground", cognite_client=self)
         self.types = TypesAPI(self._config, api_version="playground", cognite_client=self)
 
+        self.document_parsing = DocumentParsingAPI(self._config, api_version="playground", cognite_client=self)
         self.entity_matching = EntityMatchingAPI(self._config, api_version="playground", cognite_client=self)
         self.entity_extraction = EntityExtractionAPI(self._config, api_version="playground", cognite_client=self)
         self.pnid_parsing = PNIDParsingAPI(self._config, api_version="playground", cognite_client=self)
-        self.resource_typing = ResourceTypingAPI(self._config, api_version="playground", cognite_client=self)
+        self.schemas = SchemaCompletionAPI(self._config, api_version="playground", cognite_client=self)
+
         self.functions = FunctionsAPI(self.config, api_version="playground", cognite_client=self)
